#!/bin/sh

# Usage: $0 <SOURCE> <DESTINATION>
#
# Creates 0-byte file copy of the tree under SOURCE at DESTINATION.
# The directories are the same, but the files are replaced with 0-byte
# copies. This is useful for creating filesystem layout tests.

usage() {
    # this prints out the top comment
    DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
    sed -n '3,/^$/s/^#//p' ${DIR}/${BASH_SOURCE[0]} | sed 's/^ //g' | sed "s|\$0|$0|g"
}

# make sure we have the right number of arguments, or else exit
[ $# -lt 2 ] && usage && exit 1

# Decode the command line arguments
SRC=$1
DEST=$2

# Let's start by creating the destination directory
mkdir -p $DEST

# Now let's walk through all the directories under $SRC and make
# corresponding directories under $DEST
for dir in $(find ${SRC} -type d); do
    mkdir -p $(echo $dir | sed "s|$SRC|$DEST|g")
done

# Now let's walk through all the files under $SRC and touch them
# under $DEST
for file in $(find ${SRC} -type f); do
    touch $(echo $file |  sed "s|$SRC|$DEST|g")
done

# In case there's a PPR or a piperesults file, we should copy those
# manually because we actually probably do want their content
for special in $(find ${SRC} -name PPR.xml -o -iname \*piperesults\*); do
    cp $special $(echo $special | sed "s|$SRC|$DEST|g")
done

